## [0.1.9](https://github.com/sandialabs/pyscan-tlk/compare/v0.1.8...v0.1.9) (2024-09-19)


### Bug Fixes

* Update README.md ([53d13ac](https://github.com/sandialabs/pyscan-tlk/commit/53d13ac06e3d2db91ebe425dd2bd14cd980cf9de))
* Update README.md ([83113a7](https://github.com/sandialabs/pyscan-tlk/commit/83113a767d02ad8ae458f5aa40f9aa1d66140a49))



## [0.1.8](https://github.com/sandialabs/pyscan-tlk/compare/v0.1.7...v0.1.8) (2024-09-15)


### Bug Fixes

* fixed versioning again ([2cdfab8](https://github.com/sandialabs/pyscan-tlk/commit/2cdfab881eb6c0e83a0647ed6a714d1f91e77c48))
* fixed versioning again [skip ci] ([448ebfd](https://github.com/sandialabs/pyscan-tlk/commit/448ebfd002cb6752b4dcd7aac844a4a4a051bc9d))



## [0.1.7](https://github.com/sandialabs/pyscan-tlk/compare/v0.1.6...v0.1.7) (2024-09-15)


### Bug Fixes

* changed package name for pypi upload ([f2a7e15](https://github.com/sandialabs/pyscan-tlk/commit/f2a7e15aa170eea206eed6c459a006d4c8957289))
* fixed version name ([486399f](https://github.com/sandialabs/pyscan-tlk/commit/486399fd9c5c4d0ee07cb41bd1a606e0128e116e))
* Update version.json ([2bef4e5](https://github.com/sandialabs/pyscan-tlk/commit/2bef4e55d84d0ea26495a19b1cdcad57cd8fdeba))
* Update version.json [skip ci] ([299e694](https://github.com/sandialabs/pyscan-tlk/commit/299e694a083e2b2027262e51b3218d9613d2703b))
* updated version ([1eb3ac7](https://github.com/sandialabs/pyscan-tlk/commit/1eb3ac72ee24b5b32832bf88c66827094978894d))



## [0.1.6](https://github.com/sandialabs/pyscan-tlk/compare/v0.1.5...v0.1.6) (2024-09-15)


### Bug Fixes

* fixed versioning? ([84127f0](https://github.com/sandialabs/pyscan-tlk/commit/84127f0d85baf8bddf242b57ffe062023d9de16a))



## [0.1.5](https://github.com/sandialabs/pyscan-tlk/compare/v0.1.4...v0.1.5) (2024-09-13)


### Bug Fixes

* changed project name ([a462c7f](https://github.com/sandialabs/pyscan-tlk/commit/a462c7fec25c86553d50b7cf22eaed831d6e4849))



## [0.1.4](https://github.com/sandialabs/pyscan-tlk/compare/v0.1.3...v0.1.4) (2024-09-13)


### Bug Fixes

* fix file names for build and pypi ([0e71e05](https://github.com/sandialabs/pyscan-tlk/commit/0e71e05f9cb25c82ada3e579a36b237e153e958c))



## [0.1.3](https://github.com/sandialabs/pyscan-tlk/compare/v0.1.2...v0.1.3) (2024-09-13)


### Bug Fixes

* flake8 errors ([d3a8441](https://github.com/sandialabs/pyscan-tlk/commit/d3a8441aa728d92b701baf8bd0c1f1b72e981bf7))



## [0.1.2](https://github.com/sandialabs/pyscan-tlk/compare/v0.1.1...v0.1.2) (2024-09-13)


### Bug Fixes

* Fixed flake8 errors ([3beef0e](https://github.com/sandialabs/pyscan-tlk/commit/3beef0e12c3bf3f74afee28407bbc5b19919fba0))
* fixed versioning for build ([f080aa2](https://github.com/sandialabs/pyscan-tlk/commit/f080aa2fd61d079eff6641d9c4e74175d675484b))



## [0.1.1](https://github.com/sandialabs/pyscan-tlk/compare/v0.1.0...v0.1.1) (2024-09-11)


### Bug Fixes

* Tested imports, fixed enum, struct, and funcs ([9bd9b38](https://github.com/sandialabs/pyscan-tlk/commit/9bd9b38add2e6a5b4a7fc28dc349db8fd018a5d8))



# [0.1.0](https://github.com/sandialabs/pyscan-tlk/compare/f4e665f318c1b52729a80f5e8debae7e47fa6755...v0.1.0) (2024-06-10)


### Features

* Added initial versions of wrappers ([f4e665f](https://github.com/sandialabs/pyscan-tlk/commit/f4e665f318c1b52729a80f5e8debae7e47fa6755))



